 [![License](https://cdndownload2.chatopera.com/cskefu/licenses/chunsong1.0.svg)](https://www.cskefu.com/licenses/v1.html "开源许可协议")

# SDK of Chatopera Store

Chatopera Store：为软件发布者提供付费资源的收银云服务 /  Cashier cloud services for software publishers.

[https://store.chatopera.com/](https://store.chatopera.com/)

实现软件中付费资源的证书管理，比如检查配额、证书验证、续费管理等。

服务：软件证书配额、证书验证、证书续费、证书过期、发票管理。

软件开发者通过集成 Chatopera Store API/SDK 实现付费资源管理，比如春松客服中的座席作为付费资源。

# Install

```
pip install -U chatoperastore
```

# License

Copyright 2023 Beijing Huaxia Chunsong Technology Co., Ltd. <https://www.chatopera.com> 

Licensed under the Chunsong Public License, Version 1.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

 https://docs.cskefu.com/licenses/v1.html

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.